@@ -5,10 +5,12 @@
 #include <Rinternals.h>
 
 SEXP R_create_ironseed(SEXP x);
-SEXP R_create_seedseq(SEXP x, SEXP n);
 SEXP R_auto_ironseed(void);
+SEXP R_create_seedseq(SEXP x, SEXP n, SEXP k);
 
 SEXP R_base58_encode64(SEXP x);
 SEXP R_base58_decode64(SEXP x);
 
+SEXP R_ironseed_config(void);
+
 #endif
